/********************************************************************************/
/*										*/
/*	Kroenke - Database Processing (10th Edition) Chapter 11			*/
/*										*/
/*	Edited by David J. Auer							*/
/*										*/
/*	This is the Microsoft SQL Server 2000 SQL code for			*/
/*	the View Ridge Gallery database used in Chapter 11.			*/
/*										*/
/*	NOTE:  The table name TRANS is used instead of TRANSACTION.		*/
/*	As explained in Chapter 11, TRANSACITON is an SQL Server keyword,	*/
/*	and although it could be placed in square brackets as			*/
/*	[TRANASCTION], even this is not a good idea with this particulary	*/
/*	keyword.  TRANS is NOT a keyword, and does not need brackets.		*/
/*										*/
/*	NOTE:  WORK is an SQL Server keyword.  Therefore, the table name WORK 	*/
/*	is enclosed in square brackets as [WORK]. This is sufficient for this	*/
/*	particular keyword							*/
/*										*/
/*	NOTE:  For the [WORK] table, the SQL statements in Chapter 07 show	*/
/*	the column Copy appearing before the column Description,  However, 	*/
/*	in Chapter 11 this order is reversed. If this *.sql file, the		*/
/*	Chapter 11 conventions are followed.  There is an *.sql file for	*/
/*	Chapter 11 named dbp10_im_ch07_MSSQL_VRG_table_Creation			*/
/*	that follows the Chapter 07 conventions. You may want to use 		*/
/*	one variant consistently. 						*/
/*										*/
/*	NOTE:	The VRG Table structure used for Chapter 07 is also used 	*/
/*	for Chapter 08.								*/
/*										*/
/********************************************************************************/


CREATE TABLE ARTIST (
	ArtistID 	int 		NOT NULL IDENTITY (1,1),
	Name 		char(25)	NOT NULL, 
	Nationality 	char(30)	NULL,
	Birthdate 	numeric (4)	NULL, 
	DeceasedDate 	numeric (4)	NULL,

	CONSTRAINT 	ArtistPK 	PRIMARY KEY (ArtistID),
	CONSTRAINT 	ArtistAK1 	UNIQUE (Name),	
/* Nationalities are now taken care in a seperate table and a TRIGGER
	CONSTRAINT 	NationalityValues 	CHECK 
			   (Nationality IN ('Canadian', 'English', 'French', 'German', 'Mexican', 'Russian', 'Spanish', 'US')),
*/
	CONSTRAINT 	BirthValuesCheck 	CHECK (Birthdate < DeceasedDate),
	CONSTRAINT 	ValidBirthYear 		CHECK (Birthdate LIKE '[1-2][0-9][0-9][0-9]'),
	CONSTRAINT 	ValidDeathYear 		CHECK (DeceasedDate LIKE '[1-2][0-9][0-9][0-9]')
	);

CREATE TABLE [WORK] (
	WorkID 		int 		NOT NULL IDENTITY (500,1),
	Title 		char(25) 	NOT NULL,
	Description 	Varchar(1000) 	NULL DEFAULT 'Unknown provenance',
	Copy 		char(8)		NOT NULL,
	ArtistID 	int 		NOT NULL,

	CONSTRAINT 	WorkPK 		PRIMARY KEY (WorkID),
	CONSTRAINT 	WorkAK1 	UNIQUE (Title, Copy),

	CONSTRAINT 	ArtistFK 	FOREIGN KEY(ArtistID) REFERENCES ARTIST (ArtistID)
 						ON UPDATE NO ACTION
						ON DELETE NO ACTION
	);

CREATE TABLE CUSTOMER (
	CustomerID 	int 		NOT NULL IDENTITY (1000,1),
	Name 		char(25) 	NOT NULL, 
	Street 		char(30) 	NULL,
	City 		char(35) 	NULL,
	State 		char(2) 	NULL,
	ZipPostalCode	char(9)		NULL, 
	Country		char(50)	NULL,
	AreaCode 	char(3)		NULL,
	PhoneNumber 	char(8) 	NULL,
	Email		char(100) 	Null,

 	CONSTRAINT 	CustomerPK 	PRIMARY KEY (CustomerID)
/* Caused Problems and is not realistic
	CONSTRAINT 	EmailAK1 	UNIQUE (Email)
*/
	);


CREATE TABLE TRANS (
	TransactionID	int 		NOT NULL IDENTITY (100,10),
	DateAcquired 	datetime	NOT NULL, 
	AcquisitionPrice numeric (8,2)	NOT NULL,
	PurchaseDate	datetime	NULL, 
	SalesPrice 	numeric (8,2)	NULL, 
	AskingPrice	numeric (8,2)	NULL,
	CustomerID	int 		NULL,
	WorkID		int 		NOT NULL,
	CONSTRAINT 	TransactionPK 	PRIMARY KEY (TransactionID),

	CONSTRAINT 	TransactionWorkFK FOREIGN KEY(WorkID) REFERENCES WORK (WorkID)
 						ON UPDATE NO ACTION
						ON DELETE NO ACTION,

	CONSTRAINT 	TransactionCustomerFK FOREIGN KEY(CustomerID) REFERENCES CUSTOMER (CustomerID)
 						ON UPDATE NO ACTION
						ON DELETE NO ACTION,

	CONSTRAINT 	SalesPriceRange 	CHECK ((SalesPrice > 1000) AND (SalesPrice <=200000)),
	CONSTRAINT	ValidTransDate 		CHECK (DateAcquired <= PurchaseDate),
	);


CREATE TABLE CUSTOMER_ARTIST_INT(
	ArtistID 	int 		NOT NULL, 
	CustomerID 	int 		NOT NULL,
 	CONSTRAINT 	CustomerArtistPK PRIMARY KEY (ArtistID, CustomerID),
	CONSTRAINT 	Customer_Artist_Int_ArtistFK FOREIGN KEY (ArtistID)
					REFERENCES ARTIST (ArtistID)
						ON UPDATE NO ACTION
						ON DELETE CASCADE,
	CONSTRAINT 	Customer_Artist_Int_CustomerFK FOREIGN KEY (CustomerID)
					REFERENCES CUSTOMER (CustomerID)
						on UPDATE NO ACTION
						ON DELETE CASCADE
	);



CREATE TABLE PROBLEM_ACCOUNT(
	Name		char(50)	NOT NULL,
	AreaCode	char(3)		NOT NULL,
	PhoneNumber	char(8)		NOT NULL,
	CONSTRAINT	ProblemAccountPK PRIMARY KEY (Name, AreaCode, PhoneNumber)
	);


CREATE TABLE ALLOWED_NATIONALITY(
	Nationality	char(30),
	CONSTRAINT	AllowedNationalityPK PRIMARY KEY (Nationality)
	);
