/********************************************************************************/
/*										*/
/*	Kroenke - Database Processing (10th Edition) Chapter 11			*/
/*										*/
/*	Written by David M. Kroenke						*/
/*										*/
/*	Edited by David J. Auer							*/
/*										*/
/*	This is the Microsoft SQL Server 2000 SQL code for			*/
/*	the End of Chapter View Ridge Gallery database used in Project		*/
/*	Questions in Chapter 11.						*/
/*										*/
/*	This file contains the initial data for each table.			*/
/*										*/
/*	NOTE:  We will have a problem entering the surrogate key values		*/
/*	shown in the text.							*/
/*										*/
/*	The database table structure was set up using the 			*/
/*	SQL Server T/SQL keyowrd IDENTITY to create surrogate keys.		*/
/*	This means that be default we cannot enter values into any		*/
/*	column defined with INDENTITY.						*/
/*										*/
/*	To work around this, we will use the T/SQL command IDENTITY_INSERT.	*/
/*										*/
/*	When IDENTITY_INSERT is set to OFF (the default), only the DBMS		*/
/*	can enter data into the controled column in the table.			*/
/*										*/
/*	When IDENTITY_INSERT is set to ON, values can be input into the		*/
/*	controled column in the table.						*/
/*										*/
/*	IDENTITY_INSERT can only be set to ON for one table at a time.		*/
/*										*/
/*	IDENTITY_INSERT requires the use of a column list in INSERT.		*/
/*										*/
/*										*/
/*	NOTE:  For the [WORK] table, the SQL statements in Chapter 07 show	*/
/*	the column Copy appearing before the column Description,  However, 	*/
/*	in Chapter 11 this order is reversed. If this *.sql file, the		*/
/*	Chapter 11 conventions are followed.  There is an *.sql file for	*/
/*	Chapter 11 named dbp10_im_ch07_MSSQL_VRG_Insert_Dataion			*/
/*	that follows the Chapter 07 conventions. You may want to use 		*/
/*	one variant consistently. 						*/
/*										*/
/*	NOTE:	The VRG Table structure used for Chapter 07 is also used 	*/
/*	for Chapter 08.								*/
/*										*/
/********************************************************************************/


/* 	IDENTITY_INSERT allows manual insertion of IDENTITY values.       	*/
/* 	IDENTITY_INSERT can only be ON for one table at a time.           	*/
/* 	Be sure IDENTITY_INSERT is OFF for all tables. 				*/

SET IDENTITY_INSERT dbo.CUSTOMER OFF
SET IDENTITY_INSERT dbo.ARTIST OFF
SET IDENTITY_INSERT dbo.[WORK] OFF
SET IDENTITY_INSERT dbo.TRANS OFF

/********************************************************************************/			

/*	INSERT data for CUSTOMER						*/
/*										*/
/*	NOTE: 	An email address was added to CUSTOMER 1051			*/
/*		Email is an alternative key defined NULL, UNIQUE, but		*/
/*		SQL server still considered two NULLs as non-UNIQUE.		*/

/*	Set INDENTITY_INSERT to ON for CUSTOMER; 				*/
/*	reset it to OFF after CUSTOMER data is inserted.			*/

SET IDENTITY_INSERT dbo.CUSTOMER ON

INSERT INTO CUSTOMER
	(CustomerID, Name, Street, City, State, ZipPostalCode, Country, AreaCode, PhoneNumber, Email)
	VALUES (
	1000, 'Jeffrey Janes', '123 W. Elm St', 'Renton', 'WA', '98123', 'USA', '206', '555-1345', 'Customer1000@somewhere.com');

INSERT INTO CUSTOMER
	(CustomerID, Name, Street, City, State, ZipPostalCode, Country, AreaCode, PhoneNumber, Email)
	VALUES (
 	1001, 'David Smith', '813 Tumbleweed Lane', 'Loveland', 'CO', '80345', 'USA', '303', '555-5434', 'Customer1001@somewhere.com');

INSERT INTO CUSTOMER
	(CustomerID, Name, Street, City, State, ZipPostalCode, Country, AreaCode, PhoneNumber, Email)
	VALUES (
	1015, 'Tiffany Twilight', '88 - First Avenue', 'Langley', 'WA', '98114', 'USA', '206', '555-1000', 'Customer1015@somewhere.com');

INSERT INTO CUSTOMER
	(CustomerID, Name, Street, City, State, ZipPostalCode, Country, AreaCode, PhoneNumber, Email)
	VALUES (
	1033, 'Fred Smathers', '10899 - 88th Ave', 'Bainbridge Island', 'WA', '98108', 'USA', '206', '555-1234', 'Customer1033@somewhere.com');

INSERT INTO CUSTOMER
	(CustomerID, Name, Street, City, State, ZipPostalCode, Country, AreaCode, PhoneNumber, Email)
	VALUES (
	1034, 'Mary Beth Frederickson', '25 South Lafayette', 'Denver', 'CO', '80210', 'USA', '303', '555-1000', 'Customer1034@somewhere.com');

INSERT INTO CUSTOMER
	(CustomerID, Name, Street, City, State, ZipPostalCode, Country, AreaCode, PhoneNumber, Email)
	VALUES (
	1036, 'Selma Warning', '205 Burnaby', 'Vancouver', 'BC', 'V0N 1B4', 'Canada', '253', '555-1234', 'Customer1036@somewhere.com');

INSERT INTO CUSTOMER
	(CustomerID, Name, Street, City, State, ZipPostalCode, Country, AreaCode, PhoneNumber, Email)
	VALUES (
	1037, 'Susan Wu', '105 Locust Ave', 'Atlanta', 'GA', '23224', 'USA', '721', '555-1234', 'Customer1037@somewhere.com');

INSERT INTO CUSTOMER
	(CustomerID, Name, Street, City, State, ZipPostalCode, Country, AreaCode, PhoneNumber, Email)
	VALUES (
	1040, 'Donald G. Gray', '55 Bodega Ave', 'Bodega Bay', 'CA', '92114', 'USA', '705', '555-1234', 'Customer1040@somewhere.com');

INSERT INTO CUSTOMER
	(CustomerID, Name, Street, City, State, ZipPostalCode, Country, AreaCode, PhoneNumber)
	VALUES (
	1041, 'Lynda Johnson', '117 C Street', 'Washington', 'DC', '11345', 'USA', '703', '555-1000');

INSERT INTO CUSTOMER
	(CustomerID, Name, Street, City, State, ZipPostalCode, Country, AreaCode, PhoneNumber, Email)
	VALUES (
	1051, 'Chris Wilkens', '87 Highland Drive', 'Olympia', 'WA', '98008', 'USA', '206', '555-1234', 'Customer1051@somewhere.com'); 

INSERT INTO CUSTOMER
	(CustomerID, Name, Street, City, State, ZipPostalCode, Country, AreaCode, PhoneNumber, Email)
	VALUES (
 	1053, 'David Smith', '1313 Mockingbird Lane', 'Lincoln', 'NE', '68506', 'USA', '402', '488-2541', 'Customer1053@somewhere.com');


SET IDENTITY_INSERT dbo.CUSTOMER OFF

/********************************************************************************/			

/*	INSERT data for ARTIST							*/

/*	Set INDENTITY_INSERT to ON for ARTIST; 					*/
/*	reset it to OFF after ARTIST data is inserted.				*/

SET IDENTITY_INSERT dbo.ARTIST ON


INSERT INTO ARTIST (ArtistID, [Name], Nationality, Birthdate, DeceasedDate) VALUES (
	3, 'Miro', 'Spanish', 1870, 1950);
INSERT INTO ARTIST (ArtistID, [Name], Nationality, Birthdate, DeceasedDate) VALUES (
	4, 'Kandinsky', 'Russian', 1854, 1900);
INSERT INTO ARTIST (ArtistID, [Name], Nationality, Birthdate) VALUES (
	5, 'Frings', 'US', 1950);
INSERT INTO ARTIST (ArtistID, [Name], Nationality, Birthdate) VALUES (
	6, 'Klee', 'German', 1900);
INSERT INTO ARTIST (ArtistID, [Name], Nationality) VALUES (
	8, 'Moos', 'US');
INSERT INTO ARTIST (ArtistID, [Name], Nationality) VALUES (
	14, 'Tobey', 'US');
INSERT INTO ARTIST (ArtistID, [Name], Nationality) VALUES (
	15, 'Matisse', 'French');
INSERT INTO ARTIST (ArtistID, [Name], Nationality) VALUES (
	16, 'Chagall', 'French');


SET IDENTITY_INSERT dbo.ARTIST OFF



/********************************************************************************/

/*	INSERT data for CUSTOMER_ARTIST_INT					*/

/*	INDENTITY_INSERT OFF is NOT needed for CUSTOMER_ARTIST_INT -		*/
/*	There are NO surrogate keys in CUSTOMER_ARTIST_INT.			*/


INSERT INTO CUSTOMER_ARTIST_INT VALUES (3, 1036);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (5, 1015);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (5, 1034);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (5, 1041);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (5, 1051);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (8, 1034);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (8, 1041);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (14, 1001);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (14, 1015);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (14, 1033);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (14, 1034);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (14, 1036);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (14, 1040);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (14, 1041);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (14, 1051);
INSERT INTO CUSTOMER_ARTIST_INT VALUES (16, 1015);

/********************************************************************************/			

/*	INSERT data for WORK							*/
/*										*/
/*  	NOTE:	The use of the double apostrophe in				*/
/*	'From the artist''s collection' is necessary for the data to be		*/
/*	read correctly.								*/
/*										*/
/*	NOTE: In this data set, the value of Description is before Copy!	*/

/*	Set INDENTITY_INSERT to ON for WORK; 					*/
/*	reset it to OFF after WORK data is inserted.				*/

SET IDENTITY_INSERT dbo.WORK ON

INSERT INTO WORK (WorkID, Title, Description, Copy, ArtistID) VALUES (
	505, 'Mystic Fabric', 'One of the only privately held copies in excellent condition!', '99/135', 14);
INSERT INTO WORK (WorkID, Title, Description, Copy, ArtistID) VALUES (
	506, 'Mi Vida', 'Very black, but very beautiful!', '7/100', 3);
INSERT INTO WORK (WorkID, Title, Description, Copy, ArtistID) VALUES (
	507, 'Mystic Fabric', 'Some water damage, but a great image!', '105/135', 14);
INSERT INTO WORK (WorkID, Title, Description, Copy, ArtistID) VALUES (
	525, 'Northwest by Night', 'Wonderful, moody image', '37/50', 16);
INSERT INTO WORK (WorkID, Title, Description, Copy, ArtistID) VALUES (
	530, 'Slow Embers', 'From the artist''s collection', 'HC', 14);


SET IDENTITY_INSERT dbo.WORK OFF


/********************************************************************************/			


/*	INSERT data for TRANS							*/


/*	Set INDENTITY_INSERT to ON for TRANS; 					*/
/*	reset it to OFF after TRANS data is inserted.				*/

SET IDENTITY_INSERT dbo.TRANS ON


INSERT INTO TRANS (TransactionID, DateAcquired, AcquisitionPrice,
	PurchaseDate, SalesPrice, AskingPrice, CustomerID, WorkID)
 	VALUES (
	101, '7/17/1989', 28900,'10/14/1989', 46700, 47000, 1001, 505);
INSERT INTO TRANS (TransactionID, DateAcquired, AcquisitionPrice,
	PurchaseDate, SalesPrice, AskingPrice, CustomerID, WorkID)
 	VALUES (
	121, '11/17/1989', 4500.00, '11/21/2000', 9750.00, 10000, 1040, 525);
INSERT INTO TRANS (TransactionID, DateAcquired, AcquisitionPrice,
	PurchaseDate, SalesPrice, AskingPrice, CustomerID, WorkID)
 	VALUES (
	122, '2/27/1999', 8000.00, '3/15/2000', 17500.00, 175000, 1036, 525);
INSERT INTO TRANS (TransactionID, DateAcquired, AcquisitionPrice,
	PurchaseDate, SalesPrice, AskingPrice, CustomerID, WorkID)
 	VALUES (
	124, '4/7/2001', 38700.00, '8/17/2001', 73500.00, 75000, 1036, 506);
INSERT INTO TRANS (TransactionID, DateAcquired, AcquisitionPrice,
	PurchaseDate, SalesPrice, AskingPrice, CustomerID, WorkID)
 	VALUES (
	129, '11/21/2001', 6750.00, '3/18/2002', 14500.00, 15000, 1040, 507);
INSERT INTO TRANS (TransactionID, DateAcquired, AcquisitionPrice, WorkID) VALUES (
	130, '11/21/2001', 21500.00, 525);
INSERT INTO TRANS (TransactionID, DateAcquired, AcquisitionPrice,
	PurchaseDate, SalesPrice, AskingPrice, CustomerID, WorkID)
 	VALUES (
	135, '7/17/2002', 47000.00, '10/2/2002', 71500.00, 72500, 1015, 530);
INSERT INTO TRANS (TransactionID, DateAcquired, AcquisitionPrice,
	PurchaseDate, SalesPrice, AskingPrice, CustomerID, WorkID)
 	VALUES (
	100, '2/27/1974', 8750.00, '3/18/1974', 18500.00, 20000, 1015, 505);


SET IDENTITY_INSERT dbo.TRANS OFF



/********************************************************************************/

INSERT INTO PROBLEM_ACCOUNT VALUES ('Nichole Not Pay', '213', '555-1234');

INSERT INTO ALLOWED_NATIONALITY VALUES ('Canadian');
INSERT INTO ALLOWED_NATIONALITY VALUES ('English');
INSERT INTO ALLOWED_NATIONALITY VALUES ('French');
INSERT INTO ALLOWED_NATIONALITY VALUES ('German');
INSERT INTO ALLOWED_NATIONALITY VALUES ('Mexican');
INSERT INTO ALLOWED_NATIONALITY VALUES ('Russian');
INSERT INTO ALLOWED_NATIONALITY VALUES ('Spanish');
INSERT INTO ALLOWED_NATIONALITY VALUES ('US');
